import { redirect, type Actions, fail } from '@sveltejs/kit';
import type { PageServerLoad } from './$types';
import { API_URL } from '$env/static/private';

import { z } from 'zod';

export const load = (async ({ locals: { user } }) => {
	if (user) throw redirect(303, '/dashboard');
}) satisfies PageServerLoad;

const schema = z.object({
	email: z
		.string()
		.email({
			message: 'Email invalide'
		})
		.trim(),
	firstname: z.string().trim(),
	lastname: z.string().trim(),
	pseudo: z.string().trim(),
	passwd: z.string(),
	description: z.string().nullable(),
	sgroup: z.string().nullable(),
	avatar: z.string().nullable()
});

export const actions = {
	default: async (event) => {
		const data = await event.request.formData();

		const parse = schema.safeParse(Object.fromEntries(data.entries()));

		if (!parse.success) {
			const errors = parse.error.errors.map((error) => {
				const { path, message } = error;
				return { field: path[0], message };
			});
			return fail(400, { errors });
		}

		const res = await fetch(`${API_URL}/register`, {
			method: 'POST',
			body: JSON.stringify({
				...parse.data
			})
		});

		if (res.ok) {
			const token = res.headers.get('Authorization')?.split(' ')[1];

			if (!token) throw new Error('No token found');

			event.cookies.set('session', token, {
				path: '/'
			});

			throw redirect(303, '/dashboard');
		}

		if (res.status === 400) {
			const { username_valid, email_valid } = await res.json();

			const errors = [];

			if (!username_valid) {
				errors.push({
					field: 'pseudo',
					message: 'Ce pseudo est déjà utilisé'
				});
			}

			if (!email_valid) {
				errors.push({
					field: 'email',
					message: 'Cet email est déjà utilisé'
				});
			}

			return fail(400, { errors });
		}

		return fail(400, {
			errors: [{ field: 'passwd', message: "Une erreur s'est produite" }]
		});
	}
} satisfies Actions;
